Wishlist
========

A list of things we'd love to add to GliderTools and the work involved.

1. Support for raw files from Slocum gliders and Seagliders with the following additional functionality
    - Thermal lag correction for each of the gliders supported in the suggestion above.
    - Support for hadware modules by model and manufacturer
2. ...
